makernote

package
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package makernote dispatches MakerNote parsing to the appropriate manufacturer-specific sub-package based on the IFD0 Make tag value.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Parser

type Parser interface {
	// Parse decodes a raw MakerNote payload into a map of tag ID → raw value bytes.
	Parse(b []byte) (map[uint16][]byte, error)
}

Parser is implemented by each manufacturer-specific package.

func Dispatch

func Dispatch(cameraMake string) Parser

Dispatch selects the correct Parser for the given make string. Returns nil when the make is unknown or unsupported.

Directories

Path Synopsis
Package canon parses Canon MakerNote IFDs.
Package canon parses Canon MakerNote IFDs.
Package dji parses DJI drone MakerNote IFDs.
Package dji parses DJI drone MakerNote IFDs.
Package fujifilm parses Fujifilm MakerNote IFDs.
Package fujifilm parses Fujifilm MakerNote IFDs.
Package leica parses Leica MakerNote IFDs.
Package leica parses Leica MakerNote IFDs.
Package nikon parses Nikon MakerNote IFDs.
Package nikon parses Nikon MakerNote IFDs.
Package olympus parses Olympus MakerNote IFDs.
Package olympus parses Olympus MakerNote IFDs.
Package panasonic parses Panasonic/Lumix MakerNote IFDs.
Package panasonic parses Panasonic/Lumix MakerNote IFDs.
Package pentax parses Pentax MakerNote IFDs.
Package pentax parses Pentax MakerNote IFDs.
Package samsung parses Samsung MakerNote IFDs.
Package samsung parses Samsung MakerNote IFDs.
Package sigma parses Sigma MakerNote IFDs.
Package sigma parses Sigma MakerNote IFDs.
Package sony parses Sony MakerNote IFDs.
Package sony parses Sony MakerNote IFDs.

Jump to